# Copyright 2016 Red Hat, Inc.
# All Rights Reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License"); you may
# not use this file except in compliance with the License. You may obtain
# a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
# WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
# License for the specific language governing permissions and limitations
# under the License.
[
  'external',
  'internal_api',
  'storage',
  'storage_mgmt',
  'tenant',
  'management',
  'ctlplane',
].each do |network|
  Facter.add('fqdn_' + network) do
    setcode do
      hostname_parts = [
        Facter.value(:hostname),
        network.gsub('_', ''),
        Facter.value(:domain),
      ].reject { |part| part.nil? || part.empty? }
      hostname_parts.join(".")
    end
  end
end
